==> zio-aws-rds_2.12-5.17.129.1-sources.jar: zio/aws/rds/model/RebootDbInstanceRequest.scala <==
package zio.aws.rds.model
import zio.aws.rds.model.primitives.BooleanOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RebootDbInstanceRequest(
    dbInstanceIdentifier: String,
    forceFailover: scala.Option[BooleanOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest = {
    import RebootDbInstanceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest
      .builder()
      .dbInstanceIdentifier(dbInstanceIdentifier: java.lang.String)
      .optionallyWith(
        forceFailover.map(value =>
          BooleanOptional.unwrap(value): java.lang.Boolean
        )
      )(_.forceFailover)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.RebootDbInstanceRequest.ReadOnly =
    zio.aws.rds.model.RebootDbInstanceRequest.wrap(buildAwsValue())
}
object RebootDbInstanceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.RebootDbInstanceRequest =
      zio.aws.rds.model.RebootDbInstanceRequest(
        dbInstanceIdentifier,
        forceFailover.map(value => value)
      )
    def dbInstanceIdentifier: String
    def forceFailover: scala.Option[BooleanOptional]
    def getDbInstanceIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbInstanceIdentifier)
    def getForceFailover: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("forceFailover", forceFailover)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest
  ) extends zio.aws.rds.model.RebootDbInstanceRequest.ReadOnly {
    override val dbInstanceIdentifier: String =
      impl.dbInstanceIdentifier(): String
    override val forceFailover: scala.Option[BooleanOptional] = scala
      .Option(impl.forceFailover())
      .map(value => zio.aws.rds.model.primitives.BooleanOptional(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest
  ): zio.aws.rds.model.RebootDbInstanceRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rds_2.12-5.17.152.1-sources.jar: zio/aws/rds/model/RebootDbInstanceRequest.scala <==
package zio.aws.rds.model
import zio.aws.rds.model.primitives.BooleanOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RebootDbInstanceRequest(
    dbInstanceIdentifier: String,
    forceFailover: scala.Option[BooleanOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest = {
    import RebootDbInstanceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest
      .builder()
      .dbInstanceIdentifier(dbInstanceIdentifier: java.lang.String)
      .optionallyWith(forceFailover.map(value => value: java.lang.Boolean))(
        _.forceFailover
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.RebootDbInstanceRequest.ReadOnly =
    zio.aws.rds.model.RebootDbInstanceRequest.wrap(buildAwsValue())
}
object RebootDbInstanceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.RebootDbInstanceRequest =
      zio.aws.rds.model.RebootDbInstanceRequest(
        dbInstanceIdentifier,
        forceFailover.map(value => value)
      )
    def dbInstanceIdentifier: String
    def forceFailover: scala.Option[BooleanOptional]
    def getDbInstanceIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbInstanceIdentifier)
    def getForceFailover: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("forceFailover", forceFailover)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest
  ) extends zio.aws.rds.model.RebootDbInstanceRequest.ReadOnly {
    override val dbInstanceIdentifier: String =
      impl.dbInstanceIdentifier(): String
    override val forceFailover: scala.Option[BooleanOptional] =
      scala.Option(impl.forceFailover()).map(value => value: BooleanOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.RebootDbInstanceRequest
  ): zio.aws.rds.model.RebootDbInstanceRequest.ReadOnly = new Wrapper(impl)
}
